# bluetorch
pytorch skeleton project for research

- For Usage Example Take a look at https://github.com/dspoka/cucl/
- WIP
- Big Chunks that are missing is a complete train loop and DataSet/Loader Things.
- For Data things integrate directly into pytorch-nlp library, (collate, padding, batching)
- sorry haven't made requirements yet but they are Python3, pytorch .4

# Usage

# Installing Options
Three Methods:

#### A. Don't want to contribute. Want easiest setup
```shell
pip3 install bluetorch
```

#### B. Don't want to Contribute want newest features
```shell
git clone the repo
pip3 install --user bluetorch
```
- need to be outside of bluetorch directory. otherwise it may install it from pypi

#### C. Want to Contribute
```shell
git clone the repo
pip3 install --user -e bluetorch
```
